import { Component, Host, h, Prop, Watch, State } from '@stencil/core';
import { useLanguage } from '../../lib/lang';
import { defaultIconPack } from '../../lib/icons';
import storeState, { onChange } from '../../lib/store';
import { defaultConfig } from '../../exports';
/**
 * A screen which shows a meeting has ended.
 */
export class DyteEndedScreen {
  constructor() {
    /** Config object */
    this.config = defaultConfig;
    /** Icon */
    this.icon = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.message = '';
  }
  connectedCallback() {
    this.statesChanged(this.states);
    onChange('roomLeftState', () => this.statesChanged());
  }
  statesChanged(s) {
    const states = s || storeState;
    if (states != null) {
      switch (states === null || states === void 0 ? void 0 : states.roomLeftState) {
        case 'left':
          this.message = 'You left the meeting';
          break;
        case 'kicked':
          this.message = 'You were removed from the meeting';
          break;
        case 'disconnected':
          this.message = 'The call ended because the connection was lost.';
          break;
        default:
          this.message = 'The meeting ended';
      }
    }
  }
  render() {
    const states = this.states || storeState;
    return (h(Host, null,
      h("div", { class: "ctr", part: "container" },
        h("dyte-logo", { config: this.config, part: "logo" }),
        h("p", { part: "message" }, this.t(this.message)),
        (states === null || states === void 0 ? void 0 : states.roomLeftState) === 'disconnected' && (h("span", { part: "description" }, this.t('Please check your internet connection and try again.'))))));
  }
  static get is() { return "dyte-ended-screen"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-ended-screen.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-ended-screen.css"]
  }; }
  static get properties() { return {
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "UIConfig",
        "resolved": "UIConfig",
        "references": {
          "UIConfig": {
            "location": "import",
            "path": "../../types/ui-config"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Config object"
      },
      "defaultValue": "defaultConfig"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Global states"
      }
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "icon": {},
    "message": {}
  }; }
  static get watchers() { return [{
      "propName": "states",
      "methodName": "statesChanged"
    }]; }
}
