import { r as registerInstance, h, H as Host, g as getElement } from './index-74ddb327.js';
import { d as defaultConfig } from './default-ui-config-c5d610a7.js';
import { d as defaultIconPack } from './default-icon-pack-eabba256.js';
import { u as useLanguage } from './index-a214afbc.js';
import { R as Render } from './index-f7bdca7a.js';
import './default-language-04851639.js';

const dyteSpotlightGridCss = ":host{display:flex;height:100%;width:100%}main{flex:1 1 0%}aside{width:50%;max-width:var(--dyte-space-96, 384px)}:host([size='sm']),:host([size='md']){flex-direction:column}:host([size='sm']) aside,:host([size='md']) aside{height:50%;max-height:var(--dyte-space-96, 384px);width:100%;max-width:100%}";

const DyteSpotlightGrid = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Participants */
    this.participants = [];
    /** Pinned Participants */
    this.pinnedParticipants = [];
    /**
     * Aspect Ratio of participant tile
     *
     * Format: `width:height`
     */
    this.aspectRatio = '16:9';
    /** Gap between participant tiles */
    this.gap = 8;
    /** UI Config */
    this.config = defaultConfig;
    /** Icon Pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    const nonPinnedParticipants = this.participants.filter((p) => !this.pinnedParticipants.includes(p));
    return (h(Host, null, h("main", null, h(Render, { element: "dyte-simple-grid", defaults: defaults, props: {
        participants: this.pinnedParticipants,
        aspectRatio: this.aspectRatio,
        gap: this.gap,
        size: 'md',
      } })), h("aside", null, h(Render, { element: "dyte-simple-grid", defaults: defaults, props: {
        participants: nonPinnedParticipants,
        aspectRatio: this.aspectRatio,
        gap: this.gap,
        size: 'sm',
      } }))));
  }
  get host() { return getElement(this); }
};
DyteSpotlightGrid.style = dyteSpotlightGridCss;

export { DyteSpotlightGrid as dyte_spotlight_grid };
