import { ImageMessage } from '@dytesdk/web-core/types/client/DyteChat';
import { ButtonVariant } from '../components/dyte-button/dyte-button';
import { RoomLeftState } from './dyte-client';
/**
 * Screen breakpoints
 */
export declare type Size = 'sm' | 'md' | 'lg' | 'xl';
/**
 * User preferences object type which are
 * shared within the global States object.
 */
export interface UserPreferences {
  mirrorVideo?: boolean;
  muteNotificationSounds?: boolean;
  autoScroll?: boolean;
}
export interface EmojiMetaData {
  name: string;
  emoji: string;
}
/**
 * Global States object which are shared among components
 */
export interface States {
  meeting?: 'idle' | 'setup' | 'joined' | 'ended';
  page?: number;
  maxPeers?: number;
  activeMoreMenu?: boolean;
  activePermissionsMessage?: boolean;
  activeScreenShare?: boolean;
  activeSpotlight?: boolean;
  activePlugin?: boolean;
  activeRemoteAccessManager?: boolean;
  activeSettings?: boolean;
  activeSidebar?: boolean;
  activeLeaveConfirmation?: boolean;
  image?: ImageMessage;
  prefs?: UserPreferences;
  sidebar?: 'chat' | 'polls' | 'participants' | 'plugins' | 'none';
  roomLeftState?: RoomLeftState;
  [state: string]: any;
}
/**
 * Notification object type, which is used in `<dyte-notification />`.
 */
export interface Notification {
  id: string;
  message: string;
  image?: string;
  /** Duration in milliseconds, don't pass this if you want a stagnant notification */
  duration?: number;
  icon?: string;
  button?: {
    text: string;
    variant?: ButtonVariant;
    onClick: () => void;
  };
}
export declare type NetworkError = 'disconnected' | 'poorConnection' | 'connected';
export interface PollObject {
  question: string;
  options: string[];
  anonymous: boolean;
  hideVotes: boolean;
}
export interface PollOption {
  text: string;
  votes: {
    id: string;
    name: string;
  }[];
  count: number;
}
export interface Poll {
  id: string;
  question: string;
  options: PollOption[];
  anonymous: boolean;
  hideVotes: boolean;
  createdBy: string;
  createdByUserId: string;
  voted: string[];
}
